@@ -1,9 +1,9 @@
-from pathlib import Path
 import shutil
 import tempfile
+from pathlib import Path
 
 from coveo_systools.filesystem import pushd
-from coveo_systools.subprocess import check_output
+from coveo_systools.subprocess import async_check_output
 
 from coveo_stew.ci.runner import ContinuousIntegrationRunner, RunnerStatus
 from coveo_stew.environment import PythonEnvironment, PythonTool
@@ -13,8 +13,8 @@ from coveo_stew.offline_publish import offline_publish
 class CheckOutdatedRunner(ContinuousIntegrationRunner):
     name: str = "check-outdated"
 
-    def _launch(self, environment: PythonEnvironment, *extra_args: str) -> RunnerStatus:
-        if self._pyproject.lock_is_outdated:
+    async def _launch(self, environment: PythonEnvironment, *extra_args: str) -> RunnerStatus:
+        if self._pyproject.lock_is_outdated():
             self._last_output = ['The lock file is out of date: run "stew fix-outdated"']
             return RunnerStatus.CheckFailed
         return RunnerStatus.Success
@@ -23,7 +23,7 @@ class CheckOutdatedRunner(ContinuousIntegrationRunner):
 class OfflineInstallRunner(ContinuousIntegrationRunner):
     name: str = "poetry-build"
 
-    def _launch(self, environment: PythonEnvironment, *extra_args: str) -> RunnerStatus:
+    async def _launch(self, environment: PythonEnvironment, *extra_args: str) -> RunnerStatus:
         temporary_folder = Path(tempfile.mkdtemp())
         offline_install_location = temporary_folder / "wheels"
 
@@ -34,7 +34,7 @@ class OfflineInstallRunner(ContinuousIntegrationRunner):
             # make sure pip install finds everything it needs from the offline location.
             # move out to a controlled file structure so that no folder imports are possible
             with pushd(temporary_folder):
-                check_output(
+                await async_check_output(
                     *environment.build_command(
                         PythonTool.Pip,
                         "install",
@@ -51,7 +51,7 @@ class OfflineInstallRunner(ContinuousIntegrationRunner):
                             for p in self._pyproject.package.dependencies.values()
                         )
                         else "",
-                    )
+                    ),
                 )
         finally:
             shutil.rmtree(temporary_folder)
